Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApplicationSession ¶
type ApplicationSession struct {
AppID *string `json:"appId,omitempty"`
DisplayName *string `json:"displayName,omitempty"`
Namespaces []*Namespace `json:"namespaces"`
SessionID *string `json:"sessionId,omitempty"`
StatusText *string `json:"statusText,omitempty"`
TransportID *string `json:"transportId,omitempty"`
}
ApplicationSession is a descript of the application
type LaunchRequest ¶
type LaunchRequest struct {
primitives.PayloadHeaders
AppID *string `json:"appId,omitempty"`
}
LaunchRequest is a command to the receiver controller namespace to launch an application.
type Namespace ¶
type Namespace struct {
Name string `json:"name"`
}
Namespace is the channel namespace of the application
type Status ¶
type Status struct {
primitives.PayloadHeaders
Applications []*ApplicationSession `json:"applications"`
Volume *Volume `json:"volume,omitempty"`
}
Status is the general struct containing the volume as well as the current application sessions.
func (*Status) GetSessionByNamespace ¶
func (s *Status) GetSessionByNamespace(namespace string) *ApplicationSession
GetSessionByNamespace attempts to return the first session with a specified namespace.
type StatusResponse ¶
type StatusResponse struct {
primitives.PayloadHeaders
Status *Status `json:"status,omitempty"`
}
StatusResponse is the main wrapper around a receiver status
type StopRequest ¶
type StopRequest struct {
primitives.PayloadHeaders
SessionID *string `json:"sessionID,omitempty"`
}
StopRequest is a command to the receiver controller namespace to launch an application.
Click to show internal directories.
Click to hide internal directories.